@@ -7,20 +7,37 @@ from automon.integrations.mac.airport.scanner import Airport
 class AirportTest(unittest.TestCase):
     a = Airport()
 
-    def test_Airport(self):
-        if sys.platform == 'darwin':
+    def test_run(self):
+        if self.a.is_mac:
             self.assertTrue(self.a.run())
+
+    def test_scan(self):
+        if self.a.is_mac:
             self.assertTrue(self.a.scan())
             self.assertTrue(self.a.scan(0))
+
+    def test_summary(self):
+        if self.a.is_mac:
             self.assertTrue(self.a.scan_summary())
             self.assertTrue(self.a.scan_summary(0))
+
+    def test_xml(self):
+        if self.a.is_mac:
             self.assertTrue(self.a.scan_xml())
             self.assertTrue(self.a.scan_xml(0))
 
+    def test_set_channel(self):
+        if self.a.is_mac:
+            pass
             # self.assertTrue(self.a.set_channel(10))
             # self.assertTrue(self.a.disassociate())
 
+    def test_getinto(self):
+        if self.a.is_mac:
             self.assertTrue(self.a.getinfo())
+
+    def test_create_psk(self):
+        if self.a.is_mac:
             self.assertTrue(self.a.create_psk(ssid='AAAAAAAA', passphrase='CALVIN'))
 
 
